/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.helpcenter.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Operation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import vip.xiaonuo.common.annotation.CommonLog;
import vip.xiaonuo.common.pojo.CommonResult;
import vip.xiaonuo.biz.modular.helpcenter.entity.HelpCenter;
import vip.xiaonuo.biz.modular.helpcenter.param.HelpCenterAddParam;
import vip.xiaonuo.biz.modular.helpcenter.param.HelpCenterEditParam;
import vip.xiaonuo.biz.modular.helpcenter.param.HelpCenterIdParam;
import vip.xiaonuo.biz.modular.helpcenter.param.HelpCenterPageParam;
import vip.xiaonuo.biz.modular.helpcenter.service.HelpCenterService;

import jakarta.annotation.Resource;
import jakarta.validation.Valid;
import jakarta.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 帮助中心控制器
 *
 * @author fanzherong
 * @date  2025/02/05 09:38
 */
@Tag(name = "帮助中心控制器")
@RestController
@Validated
public class HelpCenterController {

    @Resource
    private HelpCenterService helpCenterService;

    /**
     * 获取帮助中心分页
     *
     * @author fanzherong
     * @date  2025/02/05 09:38
     */
    @Operation(summary = "获取帮助中心分页")
    @SaCheckPermission("/biz/helpcenter/page")
    @GetMapping("/biz/helpcenter/page")
    public CommonResult<Page<HelpCenter>> page(HelpCenterPageParam helpCenterPageParam) {
        return CommonResult.data(helpCenterService.page(helpCenterPageParam));
    }

    /**
     * 添加帮助中心
     *
     * @author fanzherong
     * @date  2025/02/05 09:38
     */
    @Operation(summary = "添加帮助中心")
    @CommonLog("添加帮助中心")
    @SaCheckPermission("/biz/helpcenter/add")
    @PostMapping("/biz/helpcenter/add")
    public CommonResult<String> add(@RequestBody @Valid HelpCenterAddParam helpCenterAddParam) {
        helpCenterService.add(helpCenterAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑帮助中心
     *
     * @author fanzherong
     * @date  2025/02/05 09:38
     */
    @Operation(summary = "编辑帮助中心")
    @CommonLog("编辑帮助中心")
    @SaCheckPermission("/biz/helpcenter/edit")
    @PostMapping("/biz/helpcenter/edit")
    public CommonResult<String> edit(@RequestBody @Valid HelpCenterEditParam helpCenterEditParam) {
        helpCenterService.edit(helpCenterEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除帮助中心
     *
     * @author fanzherong
     * @date  2025/02/05 09:38
     */
    @Operation(summary = "删除帮助中心")
    @CommonLog("删除帮助中心")
    @SaCheckPermission("/biz/helpcenter/delete")
    @PostMapping("/biz/helpcenter/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   List<HelpCenterIdParam> helpCenterIdParamList) {
        helpCenterService.delete(helpCenterIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取帮助中心详情
     *
     * @author fanzherong
     * @date  2025/02/05 09:38
     */
    @Operation(summary = "获取帮助中心详情")
    @SaCheckPermission("/biz/helpcenter/detail")
    @GetMapping("/biz/helpcenter/detail")
    public CommonResult<HelpCenter> detail(@Valid HelpCenterIdParam helpCenterIdParam) {
        return CommonResult.data(helpCenterService.detail(helpCenterIdParam));
    }

    /**
     * 获取帮助中心数据回显
     */
    @Operation(summary = "获取帮助中心数据回显")
    @SaCheckPermission("/biz/helpcenter/helpCenter")
    @GetMapping("/biz/helpcenter/helpCenter")
    public CommonResult<HelpCenter> helpCenter() {
        return CommonResult.data(helpCenterService.helpCenter());
    }
}
