/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.rechargerecord.param;

import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Getter;
import lombok.Setter;

import jakarta.validation.constraints.NotBlank;
import jakarta.validation.constraints.NotNull;
import java.math.BigDecimal;
import java.util.Date;

/**
 * 充值记录表编辑参数
 *
 * @author wulei
 * @date  2025/02/06 17:41
 **/
@Getter
@Setter
public class BizRechargeRecordEditParam {

    /** 充值记录表id */
    @Schema(description = "充值记录表id", requiredMode = Schema.RequiredMode.REQUIRED)
    @NotBlank(message = "id不能为空")
    private String id;

    /** 用户id */
    @Schema(description = "用户id")
    private String userId;

    /** 充值方案id */
    @Schema(description = "充值方案id")
    private String rechargePlanId;

    /** 充值金额 */
    @Schema(description = "充值金额")
    private BigDecimal rechargeAmount;

    /** 充值时间 */
    @Schema(description = "充值时间")
    private Date rechargeTime;

    /** 原账户余额 */
    @Schema(description = "原账户余额")
    private BigDecimal oldAccountBalance;

    /** 原代金券金额 */
    @Schema(description = "原代金券金额")
    private BigDecimal oldVoucherBalance;

    /** 新账户余额 */
    @Schema(description = "新账户余额")
    private BigDecimal newAccountBalance;

    /** 新代金券金额 */
    @Schema(description = "新代金券金额")
    private BigDecimal newVoucherBalance;

    /** 推荐人的返点比例 */
    @Schema(description = "推荐人的返点比例")
    private BigDecimal rebateRatio;

    /** 推荐人具体返点金额 */
    @Schema(description = "推荐人具体返点金额")
    private BigDecimal rebateAmount;

    /** 优惠券（蛋糕券）数量 */
    @Schema(description = "优惠券（蛋糕券）数量")
    private Integer couponNum;

    /** 优惠券金额 */
    @Schema(description = "优惠券金额")
    private BigDecimal couponAmount;

    /** 系统订单号 */
    @Schema(description = "系统订单号")
    private String orderNo;

    /** 微信订单编号 */
    @Schema(description = "微信订单编号")
    private String wxOrderNo;

    /** 是否支付 0.未支付 1.已支付 */
    @Schema(description = "是否支付 0.未支付 1.已支付")
    private Boolean isPay;

    /** 支付时间 */
    @Schema(description = "支付时间")
    private Date payTime;

}
